summaryrefslogtreecommitdiffstats
path: root/lib/kross/main/scriptguiclient.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kross/main/scriptguiclient.h')
-rw-r--r--lib/kross/main/scriptguiclient.h45
1 files changed, 23 insertions, 22 deletions
diff --git a/lib/kross/main/scriptguiclient.h b/lib/kross/main/scriptguiclient.h
index 955b55d9..af762720 100644
--- a/lib/kross/main/scriptguiclient.h
+++ b/lib/kross/main/scriptguiclient.h
@@ -23,12 +23,12 @@
#include "scriptcontainer.h"
#include "scriptaction.h"
-#include <qobject.h>
-#include <qdom.h>
+#include <tqobject.h>
+#include <tqdom.h>
#include <kurl.h>
#include <kxmlguiclient.h>
-class QWdiget;
+class TQWdiget;
namespace Kross { namespace Api {
@@ -41,28 +41,29 @@ namespace Kross { namespace Api {
* scripting code used to extend an applications functionality.
*/
class KDE_EXPORT ScriptGUIClient
- : public QObject
+ : public TQObject
, public KXMLGUIClient
{
Q_OBJECT
- //Q_PROPERTY(QString configfile READ getConfigFile WRITE setConfigFile)
+ TQ_OBJECT
+ //TQ_PROPERTY(TQString configfile READ getConfigFile WRITE setConfigFile)
public:
/// List of KAction instances.
- typedef QPtrList<KAction> List;
+ typedef TQPtrList<KAction> List;
/**
* Constructor.
*
* \param guiclient The KXMLGUIClient this \a ScriptGUIClient
* is a child of.
* \param parent The parent QWidget. If defined Qt will handle
* freeing this \a ScriptGUIClient instance else the
* caller has to take care of freeing this instance
* if not needed any longer.
*/
- explicit ScriptGUIClient(KXMLGUIClient* guiclient, QWidget* parent = 0);
+ explicit ScriptGUIClient(KXMLGUIClient* guiclient, TQWidget* tqparent = 0);
/**
* Destructor.
@@ -73,13 +74,13 @@ namespace Kross { namespace Api {
* \return true if this \a ScriptGUIClient has a \a ScriptActionCollection
* with the name \p name else false is returned.
*/
- bool hasActionCollection(const QString& name);
+ bool hasActionCollection(const TQString& name);
/**
* \return the \a ScriptActionCollection which has the name \p name
* or NULL if there exists no such \a ScriptActionCollection .
*/
- ScriptActionCollection* getActionCollection(const QString& name);
+ ScriptActionCollection* getActionCollection(const TQString& name);
/**
* \return a map of all avaiable \a ScriptActionCollection instances
@@ -88,18 +89,18 @@ namespace Kross { namespace Api {
* 1. "installedscripts" The installed collection of scripts.
* 2. "loadedscripts" The loaded scripts.
*/
- QMap<QString, ScriptActionCollection*> getActionCollections();
+ TQMap<TQString, ScriptActionCollection*> getActionCollections();
/**
* Add a new \a ScriptActionCollection with the name \p name to
* our map of actioncollections.
*/
- void addActionCollection(const QString& name, ScriptActionCollection* collection);
+ void addActionCollection(const TQString& name, ScriptActionCollection* collection);
/**
* Remove the \a ScriptActionCollection defined with name \p name.
*/
- bool removeActionCollection(const QString& name);
+ bool removeActionCollection(const TQString& name);
/**
* Reload the list of installed scripts.
@@ -111,33 +112,33 @@ namespace Kross { namespace Api {
* packagefile should be a tar.gz-archive which will be
* extracted and to the users script-directory.
*/
- bool installScriptPackage(const QString& scriptpackagefile);
+ bool installScriptPackage(const TQString& scriptpackagefile);
/**
* Uninstall the scriptpackage located in the path
* \p scriptpackagepath . This just deletes the whole
* directory.
*/
- bool uninstallScriptPackage(const QString& scriptpackagepath);
+ bool uninstallScriptPackage(const TQString& scriptpackagepath);
/**
* Load the scriptpackage's configurationfile
* \p scriptconfigfile and add the defined \a ScriptAction
* instances to the list of installed scripts.
*/
- bool loadScriptConfigFile(const QString& scriptconfigfile);
+ bool loadScriptConfigFile(const TQString& scriptconfigfile);
/**
* Load the \p document DOM-document from the scriptpackage's
* XML-configfile \p scriptconfigfile and add the defined
* \a ScriptAction instances to the list of installed scripts.
*/
- bool loadScriptConfigDocument(const QString& scriptconfigfile, const QDomDocument &document);
+ bool loadScriptConfigDocument(const TQString& scriptconfigfile, const TQDomDocument &document);
/// KXMLGUIClient overloaded method to set the XML file.
- virtual void setXMLFile(const QString& file, bool merge = false, bool setXMLDoc = true);
+ virtual void setXMLFile(const TQString& file, bool merge = false, bool setXMLDoc = true);
/// KXMLGUIClient overloaded method to set the XML DOM-document.
- virtual void setDOMDocument(const QDomDocument &document, bool merge = false);
+ virtual void setDOMDocument(const TQDomDocument &document, bool merge = false);
public slots:
@@ -145,7 +146,7 @@ namespace Kross { namespace Api {
* A KFileDialog will be displayed to let the user choose
* a scriptfile. The choosen file will be returned as KURL.
*/
- KURL openScriptFile(const QString& caption = QString::null);
+ KURL openScriptFile(const TQString& caption = TQString());
/**
* A KFileDialog will be displayed to let the user choose
@@ -168,7 +169,7 @@ namespace Kross { namespace Api {
* the defined filename to auto-detect the \a Interpreter which
* should be used for the execution.
*/
- bool executeScriptFile(const QString& file);
+ bool executeScriptFile(const TQString& file);
/**
* This method executes the \a ScriptAction \p action .
@@ -189,7 +190,7 @@ namespace Kross { namespace Api {
* Called if execution of this \a ScriptAction failed and
* displays an errormessage-dialog.
*/
- void executionFailed(const QString& errormessage, const QString& tracedetails);
+ void executionFailed(const TQString& errormessage, const TQString& tracedetails);
/**
* Called if execution of this \a ScriptAction was
@@ -41,28 +41,29 @@ namespace Kross { namespace Api {
* \param guiclient The KXMLGUIClient this \a ScriptGUIClient
* is a child of.
- * \param parent The parent QWidget. If defined Qt will handle
+ * \param tqparent The tqparent TQWidget. If defined TQt will handle
* freeing this \a ScriptGUIClient instance else the
* caller has to take care of freeing this instance